@@ -14,9 +14,73 @@ def openapp(appname):
 	from AppOpener import open
 	open(appname)
 
+def deljsonele(path):
+	import json
+	jsonfile=json.load(open(path))
+	copy=jsonfile.copy()
+	k=eval(input('Enter the Key : '))
+	del copy[k]
+	with open(path,'w') as json_file:
+		json.dump(copy,json_file)	
+
+def rejson(path):
+	import json
+	jsonfile=json.load(open(path))
+	copy=jsonfile.copy()
+	k=eval(input('Enter the Key : '))
+	v=eval(input('Enter the Value : '))
+	copy[k]=v
+	with open(path,'w') as json_file:
+		json.dump(copy,json_file)
+
+def num(n):
+	if isinstance(n,int):
+		if n==1:
+			n='1st'
+		elif n==2:
+			n='2nd'
+		elif n==3:
+			n='3rd'
+		else:
+			n=str(n)+'th'
+		return n
+	else:
+		print(err)	
+def intuple(x,index,element):
+	if isinstance(x,tuple):
+		new=()
+		if len(x)<=index:
+			new+=x+(element,)
+		else:	
+			for i,j in zip(range(len(x)),x):
+				if i==index:
+					new+=(element,)+(j,)
+				else:
+					new+=(j,)
+		return new	
+	else:
+		print(err)
+
+def instr(x,index,element):
+	if isinstance(x,str):
+		new=''
+		if len(x)<=index:
+			new+=x+element
+		else:	
+			for i,j in zip(range(len(x)),x):
+				if i==index:
+					new+=element+j
+				else:
+					new+=j
+		return new
+	else:
+		print(err)			
+
 def functions():
-	l=['translate()','ytmp4()','ytmp3()','cqrcode()','dqrcode()','summatrix()','submatrix()','reSet()','reStr()','reDict()','reList()','reTuple()','clist()','ctuple()','cdict()','cset()','pickcolor()','search()','playsong()','restart_system()','shutdown_system()','datetoday()','timenow()','say()','openfile()','weathernow()','setvoice()','voicerate()']
-	print(f'Available Functions : {l}')
+	l=['deljsonele(<path>)','rejson(<path>)','translate(<sentence>,<language>)','ytmp4(<youtube_link>)','ytmp3(<youtube_link>)','cqrcode(<link>)','summatrix(<matrix a>,<matrix b>)','submatrix(<matrix a>,<matrix b>)','intuple(<tuple>,<index>,<new_element>)','instr(<str>,<index>,<new_element>)','reSet(<old_set>,<new_element>,<old_element>)','reStr(<old_str>,<index>,<new_str>)','reDict(<old_dict>,<old_key>,<new_key>)','reList(<old_list>,<index>,<new_element>)','reTuple(<old_tuple>,<index>,<new_element>)','clist(<length_of_the_list>)','ctuple(<length_of_the_tuple>)','cdict(<length_of_the_dict>)','cset(<length_of_the_set>)','pickcolor()','search(<content>)','playsong(<path>)','restart_system()','shutdown_system()','datetoday()','timenow()','say(<content>)','openfile(<path>)','weathernow(<city_name>)','setvoice(<number_between 0 to 2>)','voicerate(<any_number>)']
+	print('Available Functions : ')
+	for i in l:
+		print(i)
 
 def summatrix(x,y):
 	import numpy as np
@@ -28,7 +92,7 @@ def submatrix(x,y):
 	result = np.array(x) - np.array(y)
 	return result
 
-def reDict(x,nele,oele):
+def reDict(x,oele,nele):
 	if isinstance(x,dict):
 		new={}
 		for i in x:
@@ -123,34 +187,36 @@ def clist(mx):
 	List=[]
 	print('Enter Values One by One \U0001F447\n')
 	for i in range(mx):
-		l=eval(input(f'Enter {i+1} Value :'))
+		l=eval(input(f'Enter {num(i+1)} Value :'))
 		List.append(l)
-	print('\nList Created Successfully \U00002714\n')
+	print('\nList Created Successfully \U00002714')
 	return List
 
 def ctuple(mx):
 	Tuple=()
 	print('Enter Values One by One \U0001F447\n')
 	for i in range(mx):
-		t=eval(input(f'Enter {i+1} Value :'))
+		t=eval(input(f'Enter {num(i+1)} Value :'))
 		Tuple+=(t,)
-	print('\nTuple Created Successfully \U00002714\n')
+	print('\nTuple Created Successfully \U00002714')
 	return Tuple
 
 def cdict(mx):
 	Dict={}
+	print('Enter Values One by One \U0001F447\n')
 	for i in range(mx):
-		key=eval(input(f'Enter the Key of No.{i+1} Element :'))
-		value=eval(input(f'Enter the Value of No.{i+1} Element :'))
+		key=eval(input(f'Enter the Key of No.{num(i+1)} Element :'))
+		value=eval(input(f'Enter the Value of No.{num(i+1)} Element :'))
+		print()
 		Dict[key]=value
-	print('\nDictionary Created Successfully \U00002714')	
+	print('Dictionary Created Successfully \U00002714')	
 	return Dict
 
 def cset(mx):
 	Set=set()
 	print('Enter Values One by One \U0001F447\n')
 	for i in range(mx):
-		s=eval(input(f'Enter {i+1} Values : '))
+		s=eval(input(f'Enter {num(i+1)} Values : '))
 		Set.add(s)
 	print('\nSet Created Successfully \U00002714')	
 	return Set
@@ -224,4 +290,4 @@ def setvoice(num):
 	engine.setProperty('voice',voices[num].id)	
 
 def voicerate(num):
-		engine.setProperty('rate',num)
\ No newline at end of file
+	engine.setProperty('rate',num)
\ No newline at end of file
